%   * dpp_test_multiclass.m
%   * Copyright (C) Manuel Fernandez Delgado 2011 <manuel.fernandez.delgado@usc.es>
%   *
%   *     This program is free software: you can redistribute it and/or modify
%   *     it under the terms of the GNU General Public License as published by
%   *     the Free Software Foundation, either version 3 of the License, or
%   *     (at your option) any later version.
%   *
%   *     This program is distributed in the hope that it will be useful,
%   *     but WITHOUT ANY WARRANTY; without even the implied warranty of
%   *     MERCHANPOILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   *     GNU General Public License for more details.
%   *
%   *     You should have received a copy of the GNU General Public License
%   *     along with this program.  If not, see <http://www.gnu.org/licenses/>.
%   *
function y = dpp_test_multiclass(w, ps, x, nc)
% DPP_TEST_MULTICLASS tests a DPP network with weights w and mean/stdev ps on a test
%    pattern x which may belong to classes 1..nc
%  Description
%  w - (nc*n x ni) weight matrix, nc is the number of classes, n is the number of parallel perceptrons, ni is the number of inputs
%  ps - the mean/stdev of the training patterns used to pre-process the test pattern x
%  x - (1 x ni) row vector with the test pattern
%  nc - no. of classes
n = size(w,1)/nc;
x = mapstd('apply', x', ps)'; x = [x 1];
s = zeros(1,nc);
vmax = -inf;
for c = 1:nc
    s(c) = 0;
    for i = 1:n
        index = (c - 1)*nc + i;
        s(c) = s(c) + dot(w(index,:),x);
    end
    if s(c) > vmax
        vmax = s(c); y = c;
    end
end

end % end of funtion